@@ -37,6 +37,7 @@ class Field:
     entityType: Optional[str] = None
     alias: Optional[str] = None
     internalDataType: Optional[str] = None
+    originalDataType: Optional[str] = None
 
 
 class SQLOperator(Enum):
@@ -160,11 +161,14 @@ class Condition:
 
 @dataclass
 class CompositeCondition:
-    operator: BooleanOperator
+    operator: Union[BooleanOperator, str]
     conditions: List[Union[Condition, 'CompositeCondition']]
 
     def __repr__(self):
-        where_condition = '( ' + (' ' + self.operator.name + ' ').join([str(c) for c in self.conditions]) + ' )'
+        if isinstance(self.operator, BooleanOperator):
+            where_condition = '( ' + (' ' + self.operator.name + ' ').join([str(c) for c in self.conditions]) + ' )'
+        else:
+            where_condition = '( ' + (' ' + self.operator + ' ').join([str(c) for c in self.conditions]) + ' )'
 
         return where_condition
 
@@ -363,7 +367,10 @@ class Query:
             spell_str += ', "order_by":['
             orderby_vec = []
             for clause in self.orderBy:
-                orderby_vec.append('"' + clause.field + " " + clause.order.name + '"')
+                if isinstance(clause.order, SQLSorting):
+                    orderby_vec.append('"' + clause.field + " " + clause.order.name + '"')
+                else:
+                    orderby_vec.append('"' + clause.field + " " + clause.order + '"')
             spell_str += ", ".join(orderby_vec) + "]"
 
         if self.limit is not None:
